@@ -90,7 +90,7 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.get(url, params, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> GET Start:")
+        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> GET Start:")
         self.logger.info(os.linesep + "---------------- URL: " + url)
 
         if params is not None:
@@ -104,7 +104,7 @@ class LoggedRequests:
         # call requests.get()
         response = requests.get(url, params, **kwargs)
 
-        self.logger.info(os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< GET Response:")
+        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< GET Response:")
         self.logger.info(response)
 
         # todo
@@ -114,7 +114,7 @@ class LoggedRequests:
             except BaseException:
                 return response
 
-        self.logger.info("========================= GET DONE =========================" + os.linesep + os.linesep)
+        self.logger.info(os.linesep + "========================= GET DONE =========================" + os.linesep + os.linesep)
 
         return response
 
@@ -154,13 +154,24 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.post(url, data, json, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> POST Start:")
+        self.logger.info(os.linesep + os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> POST Start:")
         self.logger.info(os.linesep + "------------ URL: " + url)
 
         if data is not None:
             self.logger.info(os.linesep + "------------ data start:")
-            # self.logger.info(os.linesep + self.pformat(data))
-            self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+
+            # # todo: headers type
+            # if kwargs['headers']['Content-Type'] == 'application/x-www-form-urlencoded':
+            #     self.logger.info(os.linesep + self.pformat(data))
+            # else:
+            #     self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+
+            try:
+                # 此处省去各种判断逻辑, 如果 json.loads()报错，则直接 记录原始data
+                self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+            except BaseException:
+                self.logger.info(os.linesep + self.pformat(data))
+
             self.logger.info(os.linesep + "------------ data end -------" + os.linesep)
 
         if json is not None:
@@ -174,7 +185,7 @@ class LoggedRequests:
         # call requests.post()
         response = requests.post(url, data, json, **kwargs)
 
-        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< POST Response:")
+        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< POST Response:")
         self.logger.info(response)
 
         # todo
@@ -213,13 +224,16 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.put(url, data, **kwargs)
 
-        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> PUT Start:")
+        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> PUT Start:")
         self.logger.info(os.linesep + "-------------- URL: " + url)
 
         if data is not None:
             self.logger.info(os.linesep + "------------ data:")
-            # self.logger.info(os.linesep + self.pformat(data))
-            self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+            try:
+                self.logger.info(os.linesep + self.pformat(json_func.loads(data)))
+            except BaseException:
+                self.logger.info(os.linesep + self.pformat(data))
+
 
         if len(kwargs.keys()) > 0:
             self.logger.info(os.linesep + "------------ kwargs:")
@@ -228,7 +242,7 @@ class LoggedRequests:
         # call requests.put()
         response = requests.put(url, data, **kwargs)
 
-        self.logger.info(os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< PUT Response:")
+        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< PUT Response:")
         self.logger.info(response)
 
         # todo
@@ -266,7 +280,7 @@ class LoggedRequests:
             # 直接调用 开源 requests
             return requests.delete(url, **kwargs)
 
-        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> DELETE Start:")
+        self.logger.info(os.linesep + ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> DELETE Start:")
         self.logger.info(os.linesep + "--------------- URL: " + url)
 
         if len(kwargs.keys()) > 0:
@@ -276,7 +290,7 @@ class LoggedRequests:
         # call requests.delete()
         response = requests.delete(url, **kwargs)
 
-        self.logger.info(os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< DELETE Response:")
+        self.logger.info(os.linesep + os.linesep + "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< DELETE Response:")
         self.logger.info(response)
 
         # todo
@@ -286,6 +300,6 @@ class LoggedRequests:
             except BaseException:
                 return response
 
-        self.logger.info("========================= DELETE DONE =========================" + os.linesep + os.linesep)
+        self.logger.info(os.linesep + "========================= DELETE DONE =========================" + os.linesep + os.linesep)
 
         return response
