@@ -23,7 +23,7 @@ class StartTestcaseThread(threading.Thread):
         self.executing_testcase.testcase_start_time = datetime.datetime.now()
 
         try:
-            # 执行 setup() 之前 先 log TestEngineCaseInput(如果是 test-engine 发起的)
+            # 执行 setup() 之前 先 log TestEngineCaseInput(如果是由 test-engine 发起的)
             if BaseTestCase.TestEngineCaseInput:
                 self.executing_testcase.logger.info("------ TestEngineCaseInput:")
                 self.executing_testcase.logger.info(self.executing_testcase.TestEngineCaseInput)
@@ -32,11 +32,7 @@ class StartTestcaseThread(threading.Thread):
                 self.executing_testcase.logger.info("------ execute setup() Start")
                 self.executing_testcase.setup()
                 self.executing_testcase.logger.info("------ execute setup() End")
-        except BaseException:
-            traceback.print_exc()
-            pass
 
-        try:
             if hasattr(self.executing_testcase, "runTest"):
                 print("the method runTest() is deprecated, please re-name it as run_test()")
                 self.executing_testcase.logger.info("================== runTest() start:")
